flow_id
(integer(1))
The id of the flow.
flow
(OMLFlow)
The OpenML Flow.
tags
(character())
Returns all tags of the object.
parquet
(logical(1))
Whether to use parquet.
task_id
(character(1))
The id of the task solved by this run.
task
(OMLTask)
The task solved by this run.
data_id
(integer(1))
The id of the dataset.
data
(OMLData)
The data used in this run.
task_type
(character())
The task type.
parameter_setting
data.table())
The parameter setting for this run.
prediction
(data.table())
The raw predictions of the run as returned by OpenML, not in standard mlr3 format.
Formatted predictions are accessible after converting to a mlr3::ResampleResult via
as_resample_result().
evaluation
(data.table())
The evaluations calculated by the OpenML server.