Parses a file located at path and returns a data.table().
Limitations:
Only works for dense files, no support for sparse data. Use RWeka instead.
Dates (even if there is no time component) are read in as POSIXct.
The date-format from the ARFF specification is currently ignored.
Instead, we rely on the auto-detection of data.table's fread()..
read_arff(path)(data.table()).
(character(1))
Path or URI of the ARFF file, passed to file().